@@ -12,6 +12,7 @@ class InfoData : public QObject
     Q_PROPERTY(QString component READ component WRITE setComponent NOTIFY componentChanged)
     Q_PROPERTY(QString higUrl READ higUrl NOTIFY higUrlChanged)
     Q_PROPERTY(QString sourceUrl READ sourceUrl NOTIFY sourceUrlChanged)
+    Q_PROPERTY(QString apiUrl READ apiUrl NOTIFY apiUrlChanged)
     Q_PROPERTY(QString title READ title NOTIFY titleChanged)
     Q_PROPERTY(QString text READ text NOTIFY textChanged)
 
@@ -21,6 +22,7 @@ public:
     QString component() const;
     QString higUrl() const;
     QString sourceUrl() const;
+    QString apiUrl() const;
     QString title() const;
     QString text() const;
     
@@ -30,6 +32,7 @@ signals:
     void componentChanged();
     void higUrlChanged();
     void sourceUrlChanged();
+    void apiUrlChanged();
     void titleChanged();
     void textChanged();
 
@@ -40,6 +43,7 @@ private:
     QString m_component;
     QString m_higUrl;
     QString m_sourceUrl;
+    QString m_apiUrl;
     QString m_title;
     QString m_text;
     QVariantMap m_jsonMap;
